@@ -1,4 +1,4 @@
-GOOF----LE-8-2.0 G      ]  4        h      ] g  guile	 	g  define-module*	 	 	g  language	g  glil	 		g  filenameS	
+GOOF----LE-8-2.0F      ]  4        h      ] g  guile	 	g  define-module*	 	 	g  language	g  glil	 		g  filenameS	
 f  language/glil.scm	g  importsS	g  system	
 g  base	g  syntax	
  	 	g  pmatch	
@@ -30,85 +30,86 @@ kw-prelude g  opt-prelude g  std-prelude g  program g  map   
 	Q
 		R				R			R	 			  g  nameg  
 print-glil CR4ii5R h      - 1 3   C            g  meta
-			 g  body			 g   g102787				  g  filenamef  language/glil.scm
+			 g  body			 g   g79744				  g  filenamef  language/glil.scm
 	T
  				
-	  g  nameg  make-glil-program CR4ii5R4i4ii54ii55 R4i4ii54ii55!R4ii5"R"        h      - 1 3   C          g  nreq
+	  g  nameg  make-glil-program CR4ii5R4i4ii54ii55 R4i4ii54ii55!R4ii5"R" h      - 1 3   C          g  nreq
 			 g  nlocs			 g  
-else-label				 g   g102789				  g  filenamef  language/glil.scm
+else-label				 g   g79746				  g  filenamef  language/glil.scm
 	T
  				
-	  g  nameg  make-glil-std-prelude C#R4i"i5$R4i4i"i54i"i55%R4i4i"i54i"i55&R4i4i"i54i"i55'R4ii5(R(       h       - 1 3   C              g  nreq
+	  g  nameg  make-glil-std-prelude C#R4i"i5$R4i4i"i54i"i55%R4i4i"i54i"i55&R4i4i"i54i"i55'R4ii5(R(        h       - 1 3   C              g  nreq
 			 g  nopt			 g  rest				 g  nlocs				 g  
-else-label				 g   g102791				  g  filenamef  language/glil.scm
+else-label				 g   g79748				  g  filenamef  language/glil.scm
 	T
  				
-	  g  nameg  make-glil-opt-prelude C)R4i(i5*R4i4i(i54i(i55+R4i4i(i54i(i55,R4i4i(i54i(i55-R4i4i(i54i(i55.R4i4i(i54i(i55/R4ii50R0   h      - 1 3   C         g  nreq
+	  g  nameg  make-glil-opt-prelude C)R4i(i5*R4i4i(i54i(i55+R4i4i(i54i(i55,R4i4i(i54i(i55-R4i4i(i54i(i55.R4i4i(i54i(i55/R4ii50R0    h    
+  - 1 3   C         g  nreq
 			 g  nopt			 g  rest				 g  kw				 g  allow-other-keys?				 g  nlocs				 g  
-else-label				 g   g102793				  g  filenamef  language/glil.scm
+else-label				 g   g79750				  g  filenamef  language/glil.scm
 	T
  				
-	  g  nameg  make-glil-kw-prelude C1R4i0i52R4i4i0i54i0i553R4i4i0i54i0i554R4i4i0i54i0i557R4i4i0i54i0i555R4i4i0i54i0i556R4i4i0i54i0i558R4i4i0i54i0i559R4ii5:R:     h      - 1 3   C              g  vars
-			 g   g102795			  g  filenamef  language/glil.scm
+	  g  nameg  make-glil-kw-prelude C1R4i0i52R4i4i0i54i0i553R4i4i0i54i0i554R4i4i0i54i0i557R4i4i0i54i0i555R4i4i0i54i0i556R4i4i0i54i0i558R4i4i0i54i0i559R4ii5:R:      h      - 1 3   C              g  vars
+			 g   g79752			  g  filenamef  language/glil.scm
 	T
  			
-  g  nameg  make-glil-bind C;R4i:i5<R4i4i:i54i:i55=R4ii5>R>   h      - 1 3   C            g  vars
-			 g  rest			 g   g102797				  g  filenamef  language/glil.scm
+  g  nameg  make-glil-bind C;R4i:i5<R4i4i:i54i:i55=R4ii5>R>    h      - 1 3   C            g  vars
+			 g  rest			 g   g79754				  g  filenamef  language/glil.scm
 	T
  				
-	  g  nameg  make-glil-mv-bind C?R4i>i5@R4i4i>i54i>i55AR4i4i>i54i>i55BR4ii5CRC h   y   -  1  3  C q       g   g102799
+	  g  nameg  make-glil-mv-bind C?R4i>i5@R4i4i>i54i>i55AR4i4i>i54i>i55BR4ii5CRC  h   x   -  1  3  C p       g   g79756
 			  g  filenamef  language/glil.scm
 	T
  			
 
 
-  g  nameg  make-glil-unbind CDR4iCi5ER4ii5FRF      h      - 1 3   C              g  props
-			 g   g102801			  g  filenamef  language/glil.scm
+  g  nameg  make-glil-unbind CDR4iCi5ER4ii5FRF       h      - 1 3   C              g  props
+			 g   g79758			  g  filenamef  language/glil.scm
 	T
  			
-  g  nameg  make-glil-source CGR4iFi5HR4i4iFi54iFi55IR4ii5JRJ h   w   -  1  3  C o       g   g102803
+  g  nameg  make-glil-source CGR4iFi5HR4i4iFi54iFi55IR4ii5JRJ  h   v   -  1  3  C n       g   g79760
 			  g  filenamef  language/glil.scm
 	T
  			
 
 
-  g  nameg  make-glil-void CKR4iJi5LR4ii5MRM        h      - 1 3   C              g  obj
-			 g   g102805			  g  filenamef  language/glil.scm
+  g  nameg  make-glil-void CKR4iJi5LR4ii5MRM h      - 1 3   C              g  obj
+			 g   g79762			  g  filenamef  language/glil.scm
 	T
  			
-  g  nameg  make-glil-const CNR4iMi5OR4i4iMi54iMi55PR4ii5QRQ   h      - 1 3   C        g  local?
-			 g  boxed?			 g  op				 g  index				 g   g102807				  g  filenamef  language/glil.scm
+  g  nameg  make-glil-const CNR4iMi5OR4i4iMi54iMi55PR4ii5QRQ    h      - 1 3   C        g  local?
+			 g  boxed?			 g  op				 g  index				 g   g79764				  g  filenamef  language/glil.scm
 	T
  				
-	  g  nameg  make-glil-lexical CRR4iQi5SR4i4iQi54iQi55TR4i4iQi54iQi55UR4i4iQi54iQi55VR4i4iQi54iQi55WR4ii5XRX h      - 1 3   C            g  op
-			 g  name			 g   g102809				  g  filenamef  language/glil.scm
+	  g  nameg  make-glil-lexical CRR4iQi5SR4i4iQi54iQi55TR4i4iQi54iQi55UR4i4iQi54iQi55VR4i4iQi54iQi55WR4ii5XRX  h      - 1 3   C            g  op
+			 g  name			 g   g79766				  g  filenamef  language/glil.scm
 	T
  				
-	  g  nameg  make-glil-toplevel CYR4iXi5ZR4i4iXi54iXi55[R4i4iXi54iXi55\R4ii5]R] h      - 1 3   C        g  op
-			 g  mod			 g  name				 g  public?				 g   g102811				  g  filenamef  language/glil.scm
+	  g  nameg  make-glil-toplevel CYR4iXi5ZR4i4iXi54iXi55[R4i4iXi54iXi55\R4ii5]R]  h      - 1 3   C        g  op
+			 g  mod			 g  name				 g  public?				 g   g79768				  g  filenamef  language/glil.scm
 	T
  				
-	  g  nameg  make-glil-module C^R4i]i5_R4i4i]i54i]i55`R4i4i]i54i]i55aR4i4i]i54i]i55bR4i4i]i54i]i55cR4ii5dRd     h      - 1 3   C              g  label
-			 g   g102813			  g  filenamef  language/glil.scm
+	  g  nameg  make-glil-module C^R4i]i5_R4i4i]i54i]i55`R4i4i]i54i]i55aR4i4i]i54i]i55bR4i4i]i54i]i55cR4ii5dRd      h      - 1 3   C              g  label
+			 g   g79770			  g  filenamef  language/glil.scm
 	T
  			
-  g  nameg  make-glil-label CeR4idi5fR4i4idi54idi55gR4ii5hRh h      - 1 3   C            g  inst
-			 g  label			 g   g102815				  g  filenamef  language/glil.scm
+  g  nameg  make-glil-label CeR4idi5fR4i4idi54idi55gR4ii5hRh  h      - 1 3   C            g  inst
+			 g  label			 g   g79772				  g  filenamef  language/glil.scm
 	T
  				
-	  g  nameg  make-glil-branch CiR4ihi5jR4i4ihi54ihi55kR4i4ihi54ihi55lR4ii5mRm        h      - 1 3   C            g  inst
-			 g  nargs			 g   g102817				  g  filenamef  language/glil.scm
+	  g  nameg  make-glil-branch CiR4ihi5jR4i4ihi54ihi55kR4i4ihi54ihi55lR4ii5mRm h      - 1 3   C            g  inst
+			 g  nargs			 g   g79774				  g  filenamef  language/glil.scm
 	T
  				
-	  g  nameg  make-glil-call CnR4imi5oR4i4imi54imi55pR4i4imi54imi55qR4ii5rRr  h      - 1 3   C            g  nargs
-			 g  ra			 g   g102819				  g  filenamef  language/glil.scm
+	  g  nameg  make-glil-call CnR4imi5oR4i4imi54imi55pR4i4imi54imi55qR4ii5rRr   h      - 1 3   C            g  nargs
+			 g  ra			 g   g79776				  g  filenamef  language/glil.scm
 	T
  				
-	  g  nameg  make-glil-mv-call CsR4iri5tR4i4iri54iri55uR4i4iri54iri55vR4ii5wRw h      - 1 3   C            g  label
-			 g  escape-only?			 g   g102821				  g  filenamef  language/glil.scm
+	  g  nameg  make-glil-mv-call CsR4iri5tR4i4iri54iri55uR4i4iri54iri55vR4ii5wRw  h      - 1 3   C            g  label
+			 g  escape-only?			 g   g79778				  g  filenamef  language/glil.scm
 	T
  				
-	  g  nameg  make-glil-prompt CxR4iwi5yR4i4iwi54iwi55zR4i4iwi54iwi55{Rxsnie^YRNKGD?;1)#| +       h  
+	  g  nameg  make-glil-prompt CxR4iwi5yR4i4iwi54iwi55zR4i4iwi54iwi55{Rxsnie^YRNKGD?;1)#| +h  
   ]" z" " \" " ]" " " " L" " s" " x" " " 3"  "  q $  b  &  H$  9$   (  6 6 6 6 6 6 $  R  &  <$  1$  (  6"B">":"6"2 $  R  &  <$  1$  (  6""""" $  R  	&  <$  1$  (  
 6""|"x"t"p $  ;  &  %$  (  6"2"."*"& $    
 &  u$  j&  T$  I$  4$  
